import _extends from "@babel/runtime/helpers/extends";
import cn from 'classnames';
import * as React from 'react';
export default function defaultRowRenderer({
  controlClassName,
  controlStyle,
  childrenCount,
  className,
  isOpened,
  key,
  nodeData,
  onNodeToggle,
  onRowClick,
  onRowDoubleClick,
  onRowMouseOut,
  onRowMouseOver,
  onRowRightClick,
  style
}) {
  const a11yProps = {};

  if (onRowClick || onRowDoubleClick || onRowMouseOver || onRowMouseOut || onRowRightClick) {
    a11yProps['aria-label'] = 'tree-node';
    a11yProps.tabIndex = 0;

    if (onRowClick) {
      a11yProps.onClick = event => {
        onRowClick({
          event,
          nodeData
        });
      };
    }

    if (onRowDoubleClick) {
      a11yProps.onDoubleClick = event => {
        onRowDoubleClick({
          event,
          nodeData
        });
      };
    }

    if (onRowMouseOver) {
      a11yProps.onMouseOut = event => {
        onRowMouseOver({
          event,
          nodeData
        });
      };
    }

    if (onRowMouseOut) {
      a11yProps.onMouseOver = event => {
        onRowMouseOut({
          event,
          nodeData
        });
      };
    }

    if (onRowRightClick) {
      a11yProps.onContextMenu = event => {
        onRowRightClick({
          event,
          nodeData
        });
      };
    }
  }

  const isLeaf = childrenCount === 0;
  return React.createElement("div", _extends({}, a11yProps, {
    className: cn('ReactVirtualized__Tree__node', className),
    key: key,
    style: style
  }), React.createElement("div", {
    className: controlClassName,
    style: controlStyle
  }, !isLeaf && React.createElement("button", {
    type: "button",
    onClick: onNodeToggle
  }, isOpened ? '-' : '+')), React.createElement("div", null, String(nodeData)));
}